@@ -31,7 +31,7 @@ public:
 			AcquireStmt(UByte resources, Stmt *body, Stmt *handler, const LexLocation &loc);
 
 	void	EmitActual(Bytecode &b);
-	Stmt*	Clone(Mapping *b) const;
+	Stmt*	CloneActual(Mapping *b) const;
 
 private:
 	UByte		fResources;
