@@ -22,7 +22,7 @@
 Expr* ArrayExpr::Clone(Mapping *m) const
 {
 	int newVar = m ? m->GetMappedVar(fVar) : fVar;
-	return new ArrayExpr(newVar, fExpr->Clone(m));
+	return new ArrayExpr(newVar, Get(0)->Clone(m));
 }
 
 
@@ -30,7 +30,7 @@ RCX_Value ArrayExpr::EmitAny_(Bytecode &b) const
 {
 	int value;
 	
-	if (fExpr->Evaluate(value))
+	if (Get(0)->Evaluate(value))
 	{
 		return RCX_VALUE(kRCX_VariableType,fVar + value);
 	}
@@ -39,7 +39,7 @@ RCX_Value ArrayExpr::EmitAny_(Bytecode &b) const
 	int dst = GetTempVar(b);
 	if (dst < 0)
 		return kIllegalEA;
-	fExpr->EmitTo(b, dst);
+	Get(0)->EmitTo(b, dst);
 
 	// adjust for base of array
 	if (fVar)
