@@ -18,17 +18,17 @@
 #ifndef __ArrayExpr_h
 #define __ArrayExpr_h
 
-#include "UnaryBaseExpr.h"
+#include "NodeExpr.h"
 
 #ifndef __VarTranslator_h
 #include "VarTranslator.h"
 #endif
 
 
-class ArrayExpr : public UnaryBaseExpr, public Translatable
+class ArrayExpr : public NodeExpr, public Translatable
 {
 public:
-		ArrayExpr(int var, Expr *e) : UnaryBaseExpr(e), fVar(var) {}
+		ArrayExpr(int var, Expr *e) : NodeExpr(e), fVar(var) {}
 
 	virtual Expr*		Clone(Mapping *b) const;
 	virtual bool		PromiseConstant() const	 { return false; }
