@@ -31,10 +31,10 @@ public:
 				AssignMathStmt(Expr *lval, RCX_VarCode code, Expr* value);
 				
 	void		EmitActual(Bytecode &b);
-	Stmt*		Clone(Mapping *b) const;
+	Stmt*		CloneActual(Mapping *b) const;
 	
 private:
-	void		EmitMath(Bytecode &b, int var);
+	void		EmitOperation(Bytecode &b, int var);
 	
 	RCX_VarCode	fCode;
 };
