@@ -30,7 +30,7 @@ public:
 				~AssignStmt();
 				
 	void		EmitActual(Bytecode &b);
-	Stmt*		Clone(Mapping *b) const;
+	Stmt*		CloneActual(Mapping *b) const;
 
 	virtual void	GetExprs(vector<Expr*> & v) const;
 	
