@@ -17,9 +17,9 @@
 #ifndef __BinaryExpr_h
 #define __BinaryExpr_h
 
-#include "BinaryBaseExpr.h"
+#include "NodeExpr.h"
 
-class BinaryExpr : public BinaryBaseExpr
+class BinaryExpr : public NodeExpr
 {
 public:
 			BinaryExpr(Expr *lhs, int op, Expr *rhs);
