@@ -35,16 +35,24 @@ Stmt* BlockStmt::GetChildren()
 }
 
 
-void BlockStmt::ComputeNullable()
-{
-	Stmt::ComputeNullable();
-	
-	for(Stmt *s = fList.GetHead(); s; s=s->GetNext())
-	{
-		if (!s->IsNullable()) return;
-	}
 
-	fNullable = true;
+void BlockStmt::Add(Stmt *s)
+{
+	if (s)
+	{
+		fList.InsertTail(s);
+		Adopt(s);
+	}
+}
+
+
+void BlockStmt::Prepend(Stmt *s)
+{
+	if (s)
+	{
+		fList.InsertHead(s);
+		Adopt(s);
+	}
 }
 
 
@@ -57,12 +65,16 @@ void BlockStmt::EmitActual(Bytecode &b)
 }
 
 
-Stmt* BlockStmt::Clone(Mapping *b) const
+Stmt* BlockStmt::CloneActual(Mapping *b) const
 {
 	BlockStmt *block = new BlockStmt;
 
 	for(Stmt *s = fList.GetHead(); s; s=s->GetNext())
-		block->fList.InsertTail(s->Clone(b));
+	{
+		Stmt *child = s->Clone(b);
+		block->fList.InsertTail(child);
+		block->Adopt(child);
+	}
 	
 	return block;	
 }
