@@ -31,15 +31,14 @@ public:
 	virtual Stmt*		GetChildren();
 
 
-	void			Add(Stmt *s)	{ if (s) fList.InsertTail(s); }
-	void			Prepend(Stmt *s){ if (s) fList.InsertHead(s); }
+	void			Add(Stmt *s);
+	void			Prepend(Stmt *s);
 	const Stmt*		GetHead() const	{ return fList.GetHead(); }
 	Stmt*			GetHead() 		{ return fList.GetHead(); }
 	Stmt*			RemoveHead()	{ return fList.RemoveHead(); }
 
 	virtual void	EmitActual(Bytecode &b);
-	virtual Stmt*	Clone(Mapping *b) const;
-	virtual	void	ComputeNullable();
+	virtual Stmt*	CloneActual(Mapping *b) const;
 
 private:
 	PListS<Stmt>	fList;
