@@ -14,19 +14,6 @@
  * All Rights Reserved.
  */
 
-
-/*
- * LabeledStmts are used to bind a label to another statement.  The
- * LabeledStmt isn't really a statement itself - just a wrapper for
- * a single child statement.
- *
- * Upon construction LabeledStmts are assigned their value and location.
- * During code generation of a switch statement, actual labels are
- * assigned to the LabelStmts within the switch.  Code generation for
- * LabelStmt itself only consists of setting the designated label to the
- * current bytecode locaiton.
- *
- */
  
 #ifndef __CatchStmt_h
 #define __CatchStmt_h
@@ -48,7 +35,7 @@ public:
 			~CatchStmt();
 	
 	virtual void	EmitActual(Bytecode &b);
-	virtual Stmt*	Clone(Mapping *b) const;
+	virtual Stmt*	CloneActual(Mapping *b) const;
 
 	void			SetLabel(int l)	{ fLabel = l; }
 
