@@ -31,17 +31,6 @@ DoStmt::~DoStmt()
 }
 
 
-void DoStmt::ComputeNullable()
-{
-	int v;
-	
-	Stmt::ComputeNullable();
-		
-	if (fBody->IsNullable() && fCondition->Evaluate(v) && v==0)
-		fNullable = true;
-}
-
-
 void DoStmt::EmitActual(Bytecode &b)
 {
 	/*
@@ -55,10 +44,8 @@ void DoStmt::EmitActual(Bytecode &b)
 	int cLabel = b.PushFlow(Bytecode::kContinueFlow);
 	int bLabel = b.PushFlow(Bytecode::kBreakFlow);
 	int sLabel = b.NewLabel();
-	
-	b.SetLabel(sLabel);
-	
-	fBody->Emit(b);
+		
+	GetBody()->Emit(b);
 	b.SetLabel(cLabel);
 
 	fCondition->EmitBranch(b, sLabel, true);
@@ -68,7 +55,7 @@ void DoStmt::EmitActual(Bytecode &b)
 	b.PopFlow(Bytecode::kBreakFlow);
 }
 
-Stmt* DoStmt::Clone(Mapping *b) const
+Stmt* DoStmt::CloneActual(Mapping *b) const
 {
-	return new DoStmt(fCondition->Clone(b), fBody->Clone(b));
+	return new DoStmt(fCondition->Clone(b), GetBody()->Clone(b));
 }
