@@ -24,13 +24,13 @@
 #ifndef __EventSrcExpr_h
 #define __EventSrcExpr_h
 
-#include "UnaryBaseExpr.h"
+#include "NodeExpr.h"
+#include "RCX_Target.h"
 
-
-class EventSrcExpr : public UnaryBaseExpr
+class EventSrcExpr : public NodeExpr
 {
 public:
-		EventSrcExpr(Expr *e) : UnaryBaseExpr(e) {}
+		EventSrcExpr(Expr *e, RCX_TargetType targetType) : NodeExpr(e), fTargetType(targetType) {}
 
 	virtual Expr*		Clone(Mapping *b) const;
 	
@@ -38,6 +38,9 @@ public:
 
 	virtual bool		PromiseConstant() const	{ return true; }
 	virtual bool		Evaluate(int &) const;
+
+private:	
+	RCX_TargetType		fTargetType;
 };
 
 
