@@ -38,7 +38,7 @@ void ExprStmt::EmitActual(Bytecode &b)
 }
 
 
-Stmt* ExprStmt::Clone(Mapping *b) const
+Stmt* ExprStmt::CloneActual(Mapping *b) const
 {
 	return new ExprStmt(fValue->Clone(b));
 }
