@@ -35,7 +35,7 @@ public:
 	virtual void	GetExprs(vector<Expr*> & v) const	{ if (fCondition) v.push_back(fCondition); }
 	
 	virtual void	EmitActual(Bytecode &b);
-	virtual Stmt*	Clone(Mapping *b) const;
+	virtual Stmt*	CloneActual(Mapping *b) const;
 	
 
 private:
