@@ -22,7 +22,7 @@
 
 void GosubStmt::EmitActual(Bytecode &b)
 {
-	if (!b.GetVarAllocator().CheckAvailable(fFragment->GetLocalCount()))
+	if (!b.GetVarAllocator().CheckLocalMask(fFragment->GetLocalMask()))
 	{
 		Error(kErr_NoMoreVars).Raise(&fLocation);
 		return;
@@ -35,7 +35,7 @@ void GosubStmt::EmitActual(Bytecode &b)
 }
 
 
-Stmt* GosubStmt::Clone(Mapping *) const
+Stmt* GosubStmt::CloneActual(Mapping *) const
 {
 	return new GosubStmt(fFragment, fLocation);
 }
