@@ -34,7 +34,7 @@ public:
 	
 	bool	Check(CheckState &state);
 	void	EmitActual(Bytecode &b);
-	Stmt*	Clone(Mapping *b) const;
+	Stmt*	CloneActual(Mapping *b) const;
 	Fragment*	GetFragment() const	{ return fFragment; }
 
 private:	
