@@ -31,9 +31,8 @@ public:
 			IfStmt(Expr *c, Stmt *s1, Stmt *s2=nil);
 			~IfStmt();
 	
-	void	ComputeNullable();
 	void	EmitActual(Bytecode &b);
-	Stmt*	Clone(Mapping *b) const;
+	Stmt*	CloneActual(Mapping *b) const;
 
 	virtual void	GetExprs(vector<Expr*> & v) const	{ v.push_back(fCondition); }
 
