@@ -21,7 +21,7 @@
 
 Expr* IndirectExpr::Clone(Mapping *m) const
 {
-	return new IndirectExpr(fLeft->Clone(m), fRight->Clone(m));
+	return new IndirectExpr(Get(0)->Clone(m), Get(1)->Clone(m));
 }
 
 
@@ -30,20 +30,20 @@ RCX_Value IndirectExpr::EmitAny_(Bytecode &b) const
 {
 	// decode src	
 	int src;
-	if (!fLeft->Evaluate(src))
+	if (!Get(0)->Evaluate(src))
 		return kIllegalEA;
 	int directSrc = (src >> 8) & 0xff;
 	int indirectSrc = (src) & 0xff;
 	
 	// see if direct can be used
 	int idx;
-	if (directSrc && fRight->Evaluate(idx))
+	if (directSrc && Get(1)->Evaluate(idx))
 		return RCX_VALUE(directSrc, idx);
 
 	// must use indirect
 	
 	// see if index is already in a var
-	int var = fRight->GetLValue();
+	int var = Get(1)->GetLValue();
 	if (var != kIllegalVar)
 		return RCX_VALUE(indirectSrc, var);
 
@@ -51,7 +51,7 @@ RCX_Value IndirectExpr::EmitAny_(Bytecode &b) const
 	int dst = GetTempVar(b);
 	if (dst < 0)
 		return kIllegalEA;
-	fRight->EmitTo(b, dst);
+	Get(1)->EmitTo(b, dst);
 
 	return RCX_VALUE(indirectSrc, dst) + kRCX_ValueUsesTemp;
 }
