@@ -18,13 +18,13 @@
 #ifndef __IndirectExpr_h
 #define __IndirectExpr_h
 
-#include "BinaryBaseExpr.h"
+#include "NodeExpr.h"
 
 
-class IndirectExpr : public BinaryBaseExpr
+class IndirectExpr : public NodeExpr
 {
 public:
-						IndirectExpr(Expr *src, Expr *idx) : BinaryBaseExpr(src, idx) {}
+						IndirectExpr(Expr *src, Expr *idx) : NodeExpr(src, idx) {}
 
 	virtual Expr*		Clone(Mapping *b) const;
 	virtual bool		PromiseConstant() const	 { return false; }
