@@ -17,27 +17,34 @@
 
 #include "InlineStmt.h"
 #include "Bytecode.h"
+#include "FunctionDef.h"
 
 void InlineStmt::EmitActual(Bytecode &b)
 {
+	b.AddSourceTag(
+		fFunction->GetListingEnabled() ? RCX_SourceTag::kBegin : RCX_SourceTag::kBeginNoList,
+		fFunction->GetStartLoc());
+	
 	int rLabel = b.PushFlow(Bytecode::kReturnFlow);
 	b.PushFlow(Bytecode::kContinueFlow, false);
 	b.PushFlow(Bytecode::kBreakFlow, false);
 	
-	fBody->Emit(b);
+	GetBody()->Emit(b);
 
 	b.SetLabel(rLabel);	
 
 	b.PopFlow(Bytecode::kContinueFlow);
 	b.PopFlow(Bytecode::kBreakFlow);
 	b.PopFlow(Bytecode::kReturnFlow);
+	
+	b.AddSourceTag(RCX_SourceTag::kEnd, fFunction->GetEndLoc());
 }
 
 
-Stmt* InlineStmt::Clone(Mapping *b) const
+Stmt* InlineStmt::CloneActual(Mapping *b) const
 {
 	// this never really gets called because cloning happens before
 	// InlineStmts are substituted for CallStmts.
 	
-	return new InlineStmt(fBody->Clone(b));
+	return new InlineStmt(GetBody()->Clone(b), fFunction);
 }
