@@ -28,14 +28,17 @@
  * function will exit to the correct place.
  */ 
 
+class FunctionDef;
+
 class InlineStmt : public ChainStmt
 {
 public:
-			InlineStmt(Stmt *s) : ChainStmt(s) { }
+			InlineStmt(Stmt *s, FunctionDef *f) : ChainStmt(s), fFunction(f) { }
 	void	EmitActual(Bytecode &b);
-	Stmt*	Clone(Mapping *b) const;
+	Stmt*	CloneActual(Mapping *b) const;
 
-private:	
+private:
+	FunctionDef*	fFunction;
 };
 
 
