@@ -37,7 +37,7 @@ void JumpStmt::EmitActual(Bytecode &b)
 }
 
 
-Stmt* JumpStmt::Clone(Mapping *) const
+Stmt* JumpStmt::CloneActual(Mapping *) const
 {
 	return new JumpStmt(fType, fLocation);
 }
