@@ -32,7 +32,7 @@ public:
 			JumpStmt(int type, const LexLocation &loc);
 	
 	void	EmitActual(Bytecode &b);
-	Stmt*	Clone(Mapping *b) const;
+	Stmt*	CloneActual(Mapping *b) const;
 
 private:	
 	int		fType;
