@@ -17,9 +17,9 @@
 #ifndef __LogicalExpr_h
 #define __LogicalExpr_h
 
-#include "BinaryBaseExpr.h"
+#include "NodeExpr.h"
 
-class LogicalExpr : public BinaryBaseExpr
+class LogicalExpr : public NodeExpr
 {
 public:
 		enum
