@@ -17,12 +17,12 @@
 #ifndef __ModExpr_h
 #define __ModExpr_h
 
-#include "BinaryBaseExpr.h"
+#include "NodeExpr.h"
 
-class ModExpr : public BinaryBaseExpr
+class ModExpr : public NodeExpr
 {
 public:
-			ModExpr(Expr *lhs, Expr *rhs) : BinaryBaseExpr(lhs, rhs) {};
+			ModExpr(Expr *lhs, Expr *rhs) : NodeExpr(lhs, rhs) {};
 			
 	virtual bool		Evaluate(int &value) const;
 	virtual Expr*		Clone(Mapping *b) const;
