@@ -34,7 +34,7 @@ public:
 	void	GetExprs(vector<Expr*> & v) const;
 
 	void	EmitActual(Bytecode &b);
-	Stmt*	Clone(Mapping *b) const;
+	Stmt*	CloneActual(Mapping *b) const;
 
 private:
 	Expr*		fEvents;
