@@ -20,19 +20,19 @@
 
 Expr* NegateExpr::Clone(Mapping *b) const
 {
-	return new NegateExpr(fExpr->Clone(b));
+	return new NegateExpr(Get(0)->Clone(b));
 }
 
 
 bool NegateExpr::EmitBranch_(Bytecode &b, int label, bool condition) const
 {
-	return fExpr->EmitBranch(b, label, !condition);
+	return Get(0)->EmitBranch(b, label, !condition);
 }
 
 
 bool NegateExpr::Evaluate(int &value) const
 {
-	if (!fExpr->Evaluate(value)) return false;
+	if (!Get(0)->Evaluate(value)) return false;
 	
 	value = value ? 0 : 1;
 
