@@ -19,13 +19,13 @@
 #ifndef __NegateExpr_h
 #define __NegateExpr_h
 
-#include "UnaryBaseExpr.h"
+#include "NodeExpr.h"
 
 
-class NegateExpr : public UnaryBaseExpr
+class NegateExpr : public NodeExpr
 {
 public:
-		NegateExpr(Expr *e) : UnaryBaseExpr(e) {}
+		NegateExpr(Expr *e) : NodeExpr(e) {}
 
 	virtual Expr*		Clone(Mapping *b) const;
 
