@@ -17,9 +17,9 @@
 #ifndef __RelExpr_h
 #define __RelExpr_h
 
-#include "BinaryBaseExpr.h"
+#include "NodeExpr.h"
 
-class RelExpr : public BinaryBaseExpr
+class RelExpr : public NodeExpr
 {
 public:
 			enum
