@@ -29,16 +29,9 @@ ScopeStmt::~ScopeStmt()
 }
 
 
-void ScopeStmt::ComputeNullable()
-{
-	Stmt::ComputeNullable();	
-	fNullable = fBody->IsNullable();
-}
-
-
 void ScopeStmt::EmitActual(Bytecode &b)
 {
-	fBody->EmitActual(b);
+	GetBody()->EmitActual(b);
 	
 	// release vars in the reverse order they were allocated
 	for(int i=fVariables.size()-1; i>=0; --i)
@@ -46,9 +39,9 @@ void ScopeStmt::EmitActual(Bytecode &b)
 }
 
 
-Stmt* ScopeStmt::Clone(Mapping *b) const
+Stmt* ScopeStmt::CloneActual(Mapping *b) const
 {
-	return new ScopeStmt(fBody->Clone(b));
+	return new ScopeStmt(GetBody()->Clone(b));
 }
 
 
