@@ -29,9 +29,8 @@ public:
 					ScopeStmt(Stmt *s);
 					~ScopeStmt();
 
-	void			ComputeNullable();
 	void			EmitActual(Bytecode &b);
-	Stmt*			Clone(Mapping *b) const;
+	Stmt*			CloneActual(Mapping *b) const;
 
 	void			RemapVar(int from, int to, int count);
 private:
