@@ -35,7 +35,7 @@ public:
 	
 	virtual	void	EmitActual(Bytecode &b);
 
-	Stmt*	Clone(Mapping *b) const;
+	Stmt*	CloneActual(Mapping *b) const;
 	virtual void	GetExprs(vector<Expr*> & v) const;
 
 private:	
