@@ -46,7 +46,7 @@ void TaskStmt::EmitActual(Bytecode &b)
 }
 
 
-Stmt* TaskStmt::Clone(Mapping *) const
+Stmt* TaskStmt::CloneActual(Mapping *) const
 {
 	return new TaskStmt(fOpcode, fName, fLocation);
 }
