@@ -33,7 +33,7 @@ public:
 			TaskStmt(UByte opcode, Symbol *name, const LexLocation &loc);
 	
 	void	EmitActual(Bytecode &b);
-	Stmt*	Clone(Mapping *b) const;
+	Stmt*	CloneActual(Mapping *b) const;
 
 private:	
 	Symbol*	fName;
