@@ -20,7 +20,7 @@
 
 Expr* TypeExpr::Clone(Mapping *b) const
 {
-	return new TypeExpr(fExpr->Clone(b));
+	return new TypeExpr(Get(0)->Clone(b));
 }
 
 
@@ -34,7 +34,7 @@ bool TypeExpr::Evaluate(int &value) const
 {
 	int v;
 	
-	if (fExpr->Evaluate(v))
+	if (Get(0)->Evaluate(v))
 		value = 2;
 	else
 		value = 0;
