@@ -17,12 +17,12 @@
 #ifndef __UnaryExpr_h
 #define __UnaryExpr_h
 
-#include "UnaryBaseExpr.h"
+#include "NodeExpr.h"
 
-class UnaryExpr : public UnaryBaseExpr
+class UnaryExpr : public NodeExpr
 {
 public:
-			UnaryExpr(int op, Expr *e) : UnaryBaseExpr(e), fOp(op) {}
+			UnaryExpr(int op, Expr *e) : NodeExpr(e), fOp(op) {}
 
 	virtual bool		Evaluate(int &value) const;
 	virtual Expr*		Clone(Mapping *b) const;
