@@ -20,7 +20,7 @@
 
 Expr* ValueExpr::Clone(Mapping *b) const
 {
-	return new ValueExpr(fExpr->Clone(b));
+	return new ValueExpr(Get(0)->Clone(b));
 }
 
 
@@ -28,7 +28,7 @@ RCX_Value ValueExpr::EmitAny_(Bytecode &) const
 {
 	int v;
 	
-	if (!fExpr->Evaluate(v)) return kIllegalEA;
+	if (!Get(0)->Evaluate(v)) return kIllegalEA;
 	
 	return (RCX_Value)v;
 }
@@ -38,6 +38,6 @@ RCX_Value ValueExpr::GetStaticEA_() const
 {
 	int v;
 	
-	if (!fExpr->Evaluate(v)) return kIllegalEA;
+	if (!Get(0)->Evaluate(v)) return kIllegalEA;
 	return v;
 }
