@@ -18,12 +18,12 @@
 #ifndef __ValueExpr_h
 #define __ValueExpr_h
 
-#include "UnaryBaseExpr.h"
+#include "NodeExpr.h"
 
-class ValueExpr : public UnaryBaseExpr
+class ValueExpr : public NodeExpr
 {
 public:
-		ValueExpr(Expr *e) : UnaryBaseExpr(e) {}
+		ValueExpr(Expr *e) : NodeExpr(e) {}
 
 	virtual Expr*		Clone(Mapping *b) const;
 	virtual bool		PromiseConstant() const	 { return false; }
