@@ -19,6 +19,7 @@
 
 // forward class declarations for YYSTYPE
 class Fragment;
+class Resource;
 class Stmt;
 class BlockStmt;
 class Symbol;
@@ -29,7 +30,7 @@ class FunctionDef;
 class CallStmt;
 class AsmStmt;
 class Field;
-class LabeledStmt;
+class CaseStmt;
 class DeclareStmt;
 class LocationNode;
 
