@@ -15,8 +15,7 @@
  */
 
 #ifdef WIN32
-#include <windef.h>
-#include <winbase.h>
+#include <windows.h>
 #endif
 
 #include <stdio.h>
@@ -39,8 +38,8 @@
 #include "Buffer.h"
 #include "Error.h"
 #include "Compiler.h"
-#include "RCX_Disasm.h"
 #include "CmdLine.h"
+#include "version.h"
 
 // use this to check for memory leaks in the compiler
 //#define CHECK_LEAKS
@@ -64,8 +63,6 @@
 
 FILE *gErrorStream = stderr;
 
-#define VERSION	"2.3 r1"
-
 #define kMaxPrintedErrors	10
 
 
@@ -111,7 +108,8 @@ private:
 #define kOldIncludePathEnv	"NQCC_INCLUDE"
 #define kNewIncludePathEnv	"NQC_INCLUDE"
 #define kOptionsEnv			"NQC_OPTIONS"
-#define kLowBattery	6600
+#define kLowBattery		6600
+#define kLow45Battery	3300
 
 #define kRCXFileExtension ".rcx"
 #define kNQCFileExtension ".nqc"
@@ -158,7 +156,8 @@ static const char *sTargetNames[] =
 	"rcx",
 	"cm",
 	"scout",
-	"rcx2"
+	"rcx2",
+	"spy"
 };
 
 
@@ -168,6 +167,7 @@ struct Request
 	const char *fOutputFile;
 	const char *fListFile;
 	bool	fListing;
+	bool	fSourceListing;
 	bool	fDownload;
 	bool	fBinary;
 	int		fFlags;
@@ -183,12 +183,13 @@ static char *CreateFilename(const char *source, const char *oldExt, const char *
 static const char *LeafName(const char *filename);
 static int CheckExtension(const char *s1, const char *ext);
 static RCX_Image *Compile(const char *sourceFile,  int flags);
-static bool GenerateListing(RCX_Image *image, const char *filename);
+static bool GenerateListing(RCX_Image *image, const char *filename, bool includeSource);
 static RCX_Result Download(RCX_Image *image);
 static RCX_Result UploadDatalog(bool verbose);
 static RCX_Result DownloadFirmware(const char *filename, bool fast);
 static RCX_Result SetWatch(const char *timeSpec);
 static RCX_Result SetErrorFile(const char *filename);
+static RCX_Result RedirectOutput(const char *filename);
 static RCX_Result SendRawCommand(const char *text, bool retry);
 static RCX_Result ClearMemory();
 static RCX_Result SetTarget(const char *name);
@@ -196,9 +197,12 @@ static RCX_Result SendRemote(const char *event, int repeat);
 static void PrintToken(int t, TokenVal v);
 static void PrintApi(bool compatMode);
 static bool SameString(const char *s1, const char *s2);
+static void PrintVersion();
 
 AutoLink gLink;
 RCX_TargetType gTargetType = kRCX_RCXTarget;
+bool gVerbose = false;
+int gTimeout = 0;
 
 
 int main(int argc, char **argv)
@@ -209,11 +213,11 @@ int main(int argc, char **argv)
 	gMyCompiler.AddDir(getenv(kOldIncludePathEnv));
 	gMyCompiler.AddDir(getenv(kNewIncludePathEnv));
 	
-	result = ProcessCommandLine(argc, argv);
-	gLink.Close();
-	
+	result = ProcessCommandLine(argc, argv);	
 	PrintError(result);
 
+	gLink.Close();
+
 	if (gErrorStream != stderr &&
 		gErrorStream != stdout)
 		fclose(gErrorStream);
@@ -223,7 +227,7 @@ int main(int argc, char **argv)
 #endif
 	
 	
-	return RCX_ERROR(result) ? -1 : 0;
+	return RCX_ERROR(result) ? result : 0;
 }
 
 
@@ -231,11 +235,11 @@ RCX_Result ProcessCommandLine(int argc, char ** argv)
 {
 	bool optionsOK = true;
 	bool fileProcessed = false;
-	Request req = { 0, 0, 0, false, false, false, 0 };
+	Request req = { 0 };	// rest will be zero'ed
 	CmdLine args;
 	RCX_Result result = kRCX_OK;
 	RCX_Cmd cmd;
-
+	
 	// first add environment options
 	args.Parse(getenv(kOptionsEnv));
 
@@ -282,28 +286,40 @@ RCX_Result ProcessCommandLine(int argc, char ** argv)
 					req.fFlags |= Compiler::kCompat_Flag;
 					break;
 				case 'D':
+					if  (*(a+2)=='\0') return kUsageError;
 					DefineMacro(a+2);
 					break;
 				case 'E':
 					result = SetErrorFile(a+2);
 					break;
 				case 'I':
+					if  (*(a+2)=='\0') return kUsageError;
 					gMyCompiler.AddDir(a+2);
 					break;
 				case 'L':
 					req.fListing = true;
 					req.fListFile = a[2] ? a+2 : 0;
 					break;
+				case 'R':
+					result = RedirectOutput(a+2);
+					break;
+				case 's':
+					req.fSourceListing = true;
+					break;
 				case 'O':
+					if  (*(a+2)=='\0') return kUsageError;
 					req.fOutputFile = a+2;
 					break;
 				case 'S':
+					if  (*(a+2)=='\0') return kUsageError;
 					gLink.SetSerialPort(a+2);
 					break;
 				case 'T':
+					if  (*(a+2)=='\0') return kUsageError;
 					result = SetTarget(a+2);
 					break;
 				case 'U':
+					if  (*(a+2)=='\0') return kUsageError;
 					Compiler::Get()->Undefine(a+2);
 					break;
 				case 'd':
@@ -320,18 +336,10 @@ RCX_Result ProcessCommandLine(int argc, char ** argv)
 					break;
 				case 't':
 					if (!args.Remain()) return kUsageError;
-					gLink.SetRxTimeout(args.NextInt());
+					gTimeout = args.NextInt();
 					break;
 				case 'v':
-					gLink.SetVerbose(true);
-					break;
-
-				// deprecated
-				case 'c':
-					gTargetType = kRCX_CMTarget;
-					break;
-				case 's':
-					gTargetType = kRCX_ScoutTarget;
+					gVerbose = true;
 					break;
 
 				// actions
@@ -371,7 +379,7 @@ RCX_Result ProcessCommandLine(int argc, char ** argv)
 					result = gLink.Send(cmd.Set(kRCX_AutoOffOp, (UByte)args.NextInt()));
 					break;
 				case kRunCode:
-					result = gLink.Send(cmd.Set(kRCX_StartTaskOp, 0));
+					result = gLink.Send(cmd.Set(kRCX_StartTaskOp, getTarget(gTargetType)->fRanges[kRCX_TaskChunk].fBase));
 					break;
 				case kProgramCode:
 					if (!args.Remain()) return kUsageError;
@@ -505,6 +513,7 @@ RCX_Result ProcessFile(const char *sourceFile, const Request &req)
 	RCX_Image *image;
 	RCX_Result result = kRCX_OK;
 	bool ok = true;
+	bool compiled = false;
 	
 	if (sourceFile && (req.fBinary || CheckExtension(sourceFile, kRCXFileExtension)))
 	{
@@ -521,11 +530,12 @@ RCX_Result ProcessFile(const char *sourceFile, const Request &req)
 	else
 	{
 		// compile file
+		compiled = true;
 		image = Compile(sourceFile, req.fFlags);
 		
 		if (!image)
 		{
-			int errors = ErrorHandler::Get()->GetCount();
+			int errors = ErrorHandler::Get()->GetErrorCount();
 			
 			if (errors)
 				fprintf(gErrorStream, "# %d error%s during compilation\n", errors, errors==1 ? "" : "s");
@@ -554,10 +564,15 @@ RCX_Result ProcessFile(const char *sourceFile, const Request &req)
 	// generate the listing
 	if (req.fListing)
 	{
-		if (!GenerateListing(image, req.fListFile))
+		if (!GenerateListing(image, req.fListFile, compiled && req.fSourceListing))
 			ok = false;
 	}
 
+	// reset the compiler after generating the listing so that the Compiler's
+	// buffers will be available for inserting source code into the listing
+	if (compiled)
+		Compiler::Get()->Reset();
+
 	if (req.fDownload)
 	{
 		result = Download(image);
@@ -575,7 +590,7 @@ RCX_Result ProcessFile(const char *sourceFile, const Request &req)
 }
 
 
-bool GenerateListing(RCX_Image *image, const char *filename)
+bool GenerateListing(RCX_Image *image, const char *filename, bool includeSource)
 {
 	FILE *fp;
 	
@@ -592,7 +607,7 @@ bool GenerateListing(RCX_Image *image, const char *filename)
 		fp = stdout;
 
 	RCX_StdioPrinter dst(fp);
-	image->Print(&dst);
+	image->Print(&dst, includeSource ? Compiler::Get() : 0);
 	
 	if (fp != stdout)
 		fclose(fp);
@@ -619,7 +634,8 @@ RCX_Result Download(RCX_Image *image)
 	if (!RCX_ERROR(result))
 	{
 		fprintf(STDERR, "Battery Level = %3.1f V\n", (double)result / 1000);
-		if (result < kLowBattery)
+		int lowBatt = (gTargetType==kRCX_SpyboticsTarget) ? kLow45Battery : kLowBattery;
+		if (result < lowBatt)
 			fprintf(STDERR, "*** Warning: batteries are low ***\n");
 	}
 	
@@ -677,6 +693,9 @@ RCX_Image *Compile(const char *sourceFile, int flags)
 	
 	return 0;
 #else
+	Buffer *b = new Buffer();
+	b->Create(mainBuf->GetName(), mainBuf->GetData(), mainBuf->GetLength());
+	
 	return Compiler::Get()->Compile(mainBuf, getTarget(gTargetType), flags);
 #endif
 }
@@ -744,7 +763,7 @@ RCX_Result DownloadFirmware(const char *filename, bool fast)
 	RCX_Result result;
 	ULong rom, ram;
 	
-	fp = fopen(filename, "r");
+	fp = fopen(filename, "rb");
 	if (!fp)
 	{
 		fprintf(STDERR, "Error: could not open file \'%s\'\n", filename);
@@ -762,13 +781,13 @@ RCX_Result DownloadFirmware(const char *filename, bool fast)
 
 	result = gLink.Open();
 	if (RCX_ERROR(result)) return result;
-	
+
 	fprintf(STDERR, "Downloading firmware:");
 	fflush(STDERR);
-	result = gLink.SendFirmware(srec.GetData(), srec.GetLength(), srec.GetStart(), fast);
+	result = gLink.DownloadFirmware(srec.GetData(), srec.GetLength(), srec.GetStart(), fast);
 	fputc('\n', STDERR);
 	if (RCX_ERROR(result)) return result;
-	
+
 	result = gLink.GetVersion(rom, ram);
 	if (RCX_ERROR(result)) return result;
 
@@ -919,6 +938,24 @@ RCX_Result SetErrorFile(const char *filename)
 }
 
 
+RCX_Result RedirectOutput(const char *filename)
+{
+	if (*filename==0)
+	{
+		fprintf(STDERR, "Error: -R requires a filename\n");
+		return kQuietError;
+	}
+	
+	if (!freopen(filename, "w", stdout))
+	{
+		fprintf(STDERR, "Error: could not open output file \'%s\'\n", filename);
+		return kQuietError;
+	}
+	
+	return kRCX_OK;
+}
+
+
 void DefineMacro(const char *text)
 {
 	const char *body;
@@ -961,13 +998,18 @@ void PrintError(RCX_Result error, const char *filename)
 	switch(error)
 	{
 		case kRCX_OpenSerialError:
-			fprintf(STDERR, "Could not open serial port\n");
+			fprintf(STDERR, "Could not open serial port or USB device\n");
 			break;
 		case kRCX_IREchoError:
 			fprintf(STDERR, "Problem talking to IR device\n");
 			break;
 		case kRCX_ReplyError:
-			fprintf(STDERR, "No reply from %s\n", targetName);
+			if (gLink.WasErrorFromMissingFirmware()) {
+				fprintf(STDERR, "No firmware installed on %s\n", targetName);
+			}
+			else {
+				fprintf(STDERR, "No reply from %s\n", targetName);
+			}
 			break;
 		case kRCX_MemFullError:
 			fprintf(STDERR, "Not enough free memory in %s to download program\n", targetName);
@@ -979,35 +1021,53 @@ void PrintError(RCX_Result error, const char *filename)
 			fprintf(STDERR, "File \'%s\' is not a valid RCX image\n", filename);
 			break;
 		case kUsageError:
-			fprintf(STDERR,"nqc version "VERSION" (built "__DATE__", " __TIME__")\n");
-			fprintf(STDERR,"     Copyright (C) 1998-2000 David Baum.  All Rights Reserved.\n");
+			PrintVersion();
 			fprintf(STDERR,"Usage error: try \'nqc -help\' to display options\n");
 			break;
 		case kQuietError:
 			break;
+		
+		case kRCX_PipeModeError:
+			fprintf(STDERR,"USB driver does not support -firmfast, CyberMaster, or Spybotics\n");
+			break;
+			
+		case kRCX_USBUnsupportedError:
+			fprintf(STDERR,"USB Tower not supported\n");
+			break;
+			
+		case kRCX_GhostNotFoundError:
+			fprintf(STDERR,"Ghost libraries are not installed properly\n");
+			break;
 		default:
 			fprintf(STDERR, "Error #%d\n", -error);
 			break;
 	}
 }
 
+void PrintVersion()
+{
+	fprintf(STDERR,"nqc version %s (built "__DATE__", " __TIME__")\n",
+		VERSION_STRING);
+	fprintf(STDERR,"     Copyright (C) 1998-2002 David Baum.  All Rights Reserved.\n");
+}
 
 void PrintUsage()
 {
-	fprintf(stdout,"nqc version "VERSION" (built "__DATE__", " __TIME__")\n");
-	fprintf(stdout,"     Copyright (C) 1998-2000 David Baum.  All Rights Reserved.\n");
+	PrintVersion();
 	fprintf(stdout,"Usage: nqc [options] [actions] [ - | filename ] [actions]\n");
 	fprintf(stdout,"   - : read from stdin instead of a source_file\n");	
 	fprintf(stdout,"Options:\n");	
 	fprintf(stdout,"   -1: use NQC 1.x compatability mode\n");	
-	fprintf(stdout,"   -T<target>: target can be RCX, CM, Scout, or RCX2\n");	
+	fprintf(stdout,"   -T<target>: target can be RCX, CM, Scout, RCX2, or Spy\n");	
 	fprintf(stdout,"   -d: download program\n");
 	fprintf(stdout,"   -n: prevent the system file (rcx.nqh) from being included\n");
 	fprintf(stdout,"   -b: treat input file as a binary file (don't compile it)\n");	
 	fprintf(stdout,"   -D<sym>[=<value>] : define macro <sym>\n");
 	fprintf(stdout,"   -E[<filename>] : write compiler errors to <filename> (or stdout)\n");
+	fprintf(stdout,"   -R<filename> : redirect text output (datalog, etc) to <filename>\n");
 	fprintf(stdout,"   -I<path>: search <path> for include files\n");
 	fprintf(stdout,"   -L[<filename>] : generate code listing to <filename> (or stdout)\n");
+	fprintf(stdout,"   -s : include source code in listings if possible\n");
 	fprintf(stdout,"   -O<outfile>: specify output file\n");
 	fprintf(stdout,"   -S<portname>: specify serial port\n");
 	fprintf(stdout,"   -U<sym>: undefine macro <sym>\n");
@@ -1036,8 +1096,10 @@ RCX_Result AutoLink::Open()
 	
 	if (!fOpen)
 	{
-		SetTarget(gTargetType);
-		result = RCX_Link::Open(fSerialPort);
+		ULong options = gTimeout & RCX_Link::kRxTimeoutMask;
+		if (gVerbose) options |= RCX_Link::kVerboseMode;
+		
+		result = RCX_Link::Open(gTargetType, fSerialPort, options);
 		if (RCX_ERROR(result)) return result;
 		
 		fOpen = true;
@@ -1089,7 +1151,7 @@ void MyCompiler::AddError(const Error &e, const LexLocation *loc)
 	// check the error count
 	if (!e.IsWarning())
 	{
-		int errorCount = ErrorHandler::Get()->GetCount();
+		int errorCount = ErrorHandler::Get()->GetErrorCount();
 		// only print the first few errors
 		if (errorCount > kMaxPrintedErrors)
 		{
@@ -1105,7 +1167,7 @@ void MyCompiler::AddError(const Error &e, const LexLocation *loc)
 	const char *errorType = e.IsWarning() ? "Warning" : "Error";
 	fprintf(gErrorStream, "# %s: %s\n", errorType, msg);
 
-	if (loc)
+	if (loc && loc->fIndex!=kIllegalSrcIndex)
 	{
 		Buffer *b = Compiler::Get()->GetBuffer(loc->fIndex);	
 		int lineStart = loc->fOffset;
@@ -1133,6 +1195,9 @@ void MyCompiler::AddError(const Error &e, const LexLocation *loc)
 	}
 
 	fprintf(gErrorStream, "#----------------------------------------------------------\n");
+
+	// this is a hack for Windows!
+	fflush(gErrorStream);
 }
 
 
