@@ -30,7 +30,12 @@ typedef int RCX_Result;
 #define kRCX_AbortError			-7	// canceled by RCX_Link::DownloadProgress()
 #define kRCX_MemFullError		-8	// not enough room in RCX program memory
 
-#define kRCX_LastError			-8	//	last error code
+// new error codes as of 2.4a3
+#define kRCX_PipeModeError		-9	// feature not supported by the pipe (e.g. CM target on IR tower)
+#define kRCX_USBUnsupportedError	-10	// USB is not yet supported (depends on the OS)
+#define kRCX_GhostNotFoundError		-11	// USB requires Ghost, which is not installed
+
+#define kRCX_LastError			-11	//	last error code
 
 #define RCX_ERROR(result)	((result) < 0)
 
