@@ -17,31 +17,44 @@
 #ifndef __RCX_Target_h
 #define __RCX_Target_h
 
+#ifndef __RCX_Constants_h
+#include "RCX_Constants.h"
+#endif
+
 typedef enum
 {
 	kRCX_RCXTarget = 0,	// original RCX
 	kRCX_CMTarget,		// CyberMaster
 	kRCX_ScoutTarget,	// Scout
-	kRCX_RCX2Target		// RCX 2.0
+	kRCX_RCX2Target,	// RCX 2.0
+	kRCX_SpyboticsTarget	// Spybotics
 } RCX_TargetType;
 
 
 class RCX_Target
 {
 public:
+	struct Range {
+		int	fBase;
+		int	fCount;
+	};
+	
 	RCX_TargetType	fType;
 	const char*		fName;
 	const char*		fDefine;
 	const char*		fDefValue;
-	int				fMaxTasks;
-	int				fMaxSubs;
+	
+	Range			fRanges[kRCX_ChunkTypeCount];
+	
 	int				fMaxGlobalVars;
 	int				fMaxTaskVars;
 	bool			fResources;
 	bool			fEvents;
 	bool			fArrays;
+	bool			fRestrictedMath;
 	
 	bool			SourceWritable(int source) const;
+	int				GetChunkLimit(RCX_ChunkType type) const;
 };
 
 
